@@ -29,10 +29,10 @@ class IsModerator(object):
         #print view_kwargs['slug']
 
         functionlist = ['PostUpdate', 'PostDelete', 'TopicAction', 'TopicDelete']
-        if view_func.__name__ in functionlist:
 
         try:
-            if any(view_func.__name__ in s for s in functionlist):
+            if view_func.__name__ in functionlist:
+            #if any(view_func.__name__ in s for s in functionlist):
                 if view_kwargs['topicslug']:
                     if utils.es_moderador(request.user, view_kwargs['topicslug']):
                         return None
